==> sale-1.0.8-aode.jar: revenue/sqls/charge/getUser.sql <==
select
  i.f_userinfo_code,
  i.f_olduserinfo_code,
  i.f_userinfo_id,
  i.f_user_state,
  i.f_user_name,
  i.f_user_phone,
  i.f_balance,
  i.f_idnumber,
  i.f_credentials,
  i.f_people_num,
  i.f_comments,
  i.f_book_no,
  i.f_createfile_date,
  i.f_open_date,
  i.version as userinfo_version,
  u.f_user_id,
  u.f_userfiles_id,
  u.f_remanent_price,
  u.f_remanent_gas,
  u.f_remanent_type,
  u.f_remanent_money,
  u.f_deduction_gas,
  u.f_table_state,
  u.f_card_id,
  u.f_card_password,
  u.f_meterid,
  u.f_area_code,
  u.f_tag,
  u.f_meternumber,
  u.f_metertitles,
  u.f_times,
  u.f_iot_times,
  u.f_fillcard_times,
  u.f_price_id,
  u.f_gasbrand_id,
  u.f_gasmodel_id,
  u.f_user_type,
  u.f_gasproperties,
  u.f_aroundmeter,
  u.f_meter_base,
  u.f_initial_base,
  u.f_total_gas,
  u.f_total_fee,
  u.f_whether_hairpin,
  u.f_balance_amount,
  u.f_balance_gas,
  u.version,
  u.f_filialeid,
  u.f_orgname,
  u.f_depid,
  u.f_depname,
  u.f_input_date,
  u.f_hand_date,
  u.f_gas_date,
  u.f_gas_person,
  u.f_position,
--   u.f_gas_date_2,
  address.f_address,
  gb.id as brand_id,
  gb.f_meter_type,
  gb.f_meter_brand,
  gb.f_alias,
  gb.f_collection_type,
  gb.f_calculation,
  gb.f_isdecimal,
  gb.f_topup_ceil,
  gb.f_hascard,
  gm.f_meter_style,
  gm.f_coding,
  sp.id as f_stairprice_id,
  sp.f_price_type,
  sp.f_price_name,
  sp.f_version,
  u.f_garbage_fee
from t_userfiles u
  LEFT JOIN  t_userinfo i
    on u.f_userinfo_id = i.f_userinfo_id
  LEFT JOIN t_user_address address
    on u.f_useraddress_id = address.id
  LEFT JOIN t_gasbrand gb
    on u.f_gasbrand_id = gb.id
  LEFT JOIN t_gasmodel gm
    on u.f_gasmodel_id = gm.id
  LEFT JOIN
  (select * from  t_stairprice
  where getdate()>=f_perform_date and getdate()<=f_end_date
        and f_state = '有效'
  ) sp on u.f_price_id = sp.f_price_id
  and  u.f_filialeid = sp.f_filialeid
where  {condition}  and  f_user_state = '正常' and u.f_table_state != '换表' and u.f_table_state != '无效'
order by u.f_userfiles_id desc

==> sale-1.0.40-aode.jar: revenue/sqls/charge/getUser.sql <==
select
  i.f_userinfo_code,
  i.f_olduserinfo_code,
  i.f_userinfo_id,
  i.f_user_state,
  i.f_user_name,
  i.f_user_phone,
  i.f_balance,
  i.f_idnumber,
  i.f_credentials,
  i.f_people_num,
  i.f_comments f_userinfo_comments,
  u.f_comments f_userfiles_comments,
  i.f_book_no,
  i.f_createfile_date,
  i.f_open_date,
  i.version as userinfo_version,
  i.f_user_level,
  u.f_user_id,
  u.f_userfiles_id,
  u.f_remanent_price,
  u.f_remanent_gas,
  u.f_remanent_type,
  u.f_remanent_money,
  u.f_deduction_gas,
  u.f_table_state,
  u.f_card_id,
  u.f_card_password,
  u.f_meterid,
  u.f_area_code,
  u.f_tag,
  u.f_meternumber,
  u.f_metertitles,
  u.f_times,
  u.f_iot_times,
  u.f_fillcard_times,
  u.f_price_id,
  u.f_gasbrand_id,
  u.f_gasmodel_id,
  u.f_user_type,
  u.f_gasproperties,
  u.f_aroundmeter,
  u.f_meter_base,
  u.f_initial_base,
  u.f_total_gas,
  u.f_total_fee,
  u.f_history_gas,
  u.f_history_fee,
  u.f_whether_hairpin,
  u.f_balance_amount,
  u.f_balance_gas,
  u.version,
  u.f_filialeid,
  u.f_orgname,
  u.f_depid,
  u.f_depname,
  u.f_input_date,
  u.f_hand_date,
  u.f_gas_date,
  u.f_gas_person,
  u.f_position,
  u.f_flowmeternumber,  --流量计表号
--   u.f_gas_date_2,
  address.f_address,
  address.f_last_check_date,
  gb.id as brand_id,
  gb.f_meter_type,
  gb.f_meter_brand,
  gb.f_alias,
  gb.f_collection_type,
  gb.f_calculation,
  gb.f_isdecimal,
  gb.f_topup_ceil,
  gb.f_hascard,
  gm.f_meter_style,
  gm.f_coding,
  sp.id as f_stairprice_id,
  sp.f_price_type,
  sp.f_price_name,
  sp.f_version,
  u.f_garbage_fee
from (select *,case when f_price_id is null or f_gasbrand_id is null or f_gasmodel_id is null then '1' else '0' end f_closeuserinfo from t_userfiles with(nolock)) u
  LEFT JOIN  t_userinfo i with(nolock)
    on u.f_userinfo_id = i.f_userinfo_id
  LEFT JOIN t_user_address address with(nolock)
    on u.f_useraddress_id = address.id
  LEFT JOIN t_gasbrand gb with(nolock)
    on u.f_gasbrand_id = gb.id
  LEFT JOIN t_gasmodel gm with(nolock)
    on u.f_gasmodel_id = gm.id
  LEFT JOIN
  (select * from  t_stairprice with(nolock)
  where getdate()>=f_perform_date and getdate()<=f_end_date
        and f_state = '有效'
  ) sp on u.f_price_id = sp.f_price_id
  and  u.f_filialeid = sp.f_filialeid
where  {condition}  and  f_user_state = '正常' and u.f_table_state != '换表' and u.f_table_state != '无效'
order by u.f_userfiles_id desc
